<p class="centered">simple presentation(s) site for quick slides from markdown <br>
    (powered by LaTeX beamer, pandoc, and the rust uutils)</p>
<p class="centered"><b>✨ latest feature update:</b> addition of 16:9 themes 🚀</p>
<hr>
