<hr/>
<a href="../index.php">home</a>
<a href="../index.php#how-to">how-to</a>
<a href="../info.php">info</a>
<a href="../licenses.php">licenses</a>
<br>
<p>all site content is in the public domain</p>
<p><small>my other stuff: <a href="https://aedrielkylejavier.me/" target="_blank">website link →</a></small></p>
