<!DOCTYPE html>
<html lang=en>

<head>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <meta http-equiv='cache-control' content='no-cache'>
    <meta http-equiv='expires' content='0'>
    <meta http-equiv='pragma' content='no-cache'>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>procrastiSlides: great for procratinators who need to get a presentation out, quick! 😆</title>
    <meta name="description" content="create .pdf presentations from markdown! 🤗 procrastiSlides is a simple presentation(s) site that respects your dark mode setting and has responsive web design.
         non-intruisive ads, no tracking, nothing but quick slides from plain text/markdown. 🏫 try copy and pasting your school notes! that might even work 😂">
    <meta name="color-scheme" content="light dark"> 
</head>

<body>
    <?php
    include "includes/link-tags.php";
    include "includes/license-banner.php";
    include "includes/secondary-info.php";
    include "includes/nav-header.php";
    ?>
    <h3>licenses</h3>
    <ul>
        <li> <a href="gpl2.php"> pandoc's license (gnu gpl v2)</a> </li>
        <li><a href="LaTeX.php"> The LaTeX Project Public License (1.3)</a></li>
        <li><a href="mit.php"> SimpleMDE's license (mit)</a></li>
        <li><a href="isc.php"> suckless sent's license (isc)</a></li>

    </ul>

    <h3>related links</h3>
    <ul>
        <li> <a target="_blank" href="https://pandoc.org/">pandoc.org</a> </li>
        <li>SimpleMDE's <a target="_blank" href="https://github.com/sparksuite/simplemde-markdown-editor">github</a> </li>
        <li> <a target="_blank" href="https://www.latex-project.org/">LaTeX-project.org</a> </li>
        <li>rust <a target="_blank" href="https://github.com/uutils/coreutils/">uutils/coreutils</a> project</li>
    </ul>
    </div>

    <br><br><br>
    <footer>

        <?php include "includes/nav-footer.php"; ?>

    </footer>
</body>

</html>
