<div class="centered">
   <h2>
      <a href="../index.php">home</a>
      <a href="./index.php#how-to">how-to</a>
      <a href="../info.php">info</a>
      <a href="../licenses.php">licenses</a>
   </h2>
   <hr>


 </div>
